@@ -2,9 +2,7 @@
 #
 # Redland.pm - Redland top level Perl module
 #
-# $Id: Redland.pm.in 10592 2006-03-05 08:28:27Z cmdjb $
-#
-# Copyright (C) 2000-2005 David Beckett - http://purl.org/net/dajobe/
+# Copyright (C) 2000-2005 David Beckett - http://www.dajobe.org/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software or Open Source available under the
@@ -85,7 +83,7 @@ package RDF::Redland;
 
 use vars qw($VERSION $Debug $World $Error_Sub $Warning_Sub);
 
-$VERSION= eval sprintf("%s.%02d_%02d_%02d", split(/\./, "1.0.7.1"));
+$VERSION= eval sprintf("%s.%02d_%02d_%02d", split(/\./, "1.0.8.1"));
 
 $Debug=0;
 
@@ -233,7 +231,7 @@ and L<RDF::Redland::RSS>.
 
 =head1 AUTHOR
 
-Dave Beckett - http://purl.org/net/dajobe/
+Dave Beckett - http://www.dajobe.org/
 
 =cut
 
