@@ -2,8 +2,6 @@
 # 
 # redlandtest.py - Redland Python RDF model unit tests
 #
-# $Id: redlandtest.py 13266 2007-12-12 21:32:58Z laalto $
-#
 # Authors:
 #   Matt Biddulph <mb@picdiary.com>
 #   Edd Dumbill <edd@usefulinc.com>
@@ -206,7 +204,7 @@ class RedlandStreamsCase(unittest.TestCase):
     def testFindStatements1(self):
         self.parser.parse_into_model(self.model,"file:../data/dc.rdf")
         statement = Statement(
-                Uri("http://purl.org/net/dajobe/"),
+                Uri("http://www.dajobe.org/"),
                 None, None)
 
         count = 0
@@ -218,7 +216,7 @@ class RedlandStreamsCase(unittest.TestCase):
     def testContains(self):
         self.parser.parse_into_model(self.model,"file:../data/dc.rdf")
         statement = Statement(
-                Uri("http://purl.org/net/dajobe/"),
+                Uri("http://www.dajobe.org/"),
                 Uri("http://purl.org/dc/elements/1.1/creator"), 
                 "Dave Beckett")
 
@@ -235,7 +233,7 @@ class RedlandStreamsCase(unittest.TestCase):
         for s in self.parser.parse_as_stream(a):
             self.model.append (s, intended_context)
 
-        subject = Node(Uri("http://purl.org/net/dajobe/"))
+        subject = Node(Uri("http://www.dajobe.org/"))
         statement = Statement(subject, None, None)
 
         count = 0
@@ -365,7 +363,7 @@ class RasqalQueryTestCase (unittest.TestCase):
         q = SPARQLQuery("PREFIX dc: <http://purl.org/dc/elements/1.1/> SELECT * WHERE {?a dc:title ?c}")
 
         r = q.execute(self.model)
-        expect = 377
+        expect = 372
         self.assert_(r is not None, "execute to_string should have succeeded")
         s = r.to_string()
         self.assert_(len(s) == expect, "to_string should have returned "+str(expect)+" not " + str(len(s)))
@@ -406,7 +404,7 @@ class RasqalQueryTestCase (unittest.TestCase):
         q = SPARQLQuery("PREFIX dc: <http://purl.org/dc/elements/1.1/> CONSTRUCT {?a dc:title ?c} WHERE {?a dc:title ?c}")
 
         r = q.execute(self.model)
-        expect = 294
+        expect = 289
         self.assert_(r is not None, "execute to_string should have succeeded")
         s = r.to_string()
         self.assert_(len(s) == expect, "to_string should have returned "+str(expect)+" not " + str(len(s)))
